Program APOGEU_1p1

! Carlos H. Marchi
! DEMEC/UFPR, Curitiba, PR
! verso original 1.0: 29 Out 08
! verso atual    1.1:  1 Nov 08
! ltima alterao:     1 Nov 08

! -----------------------------------------------------------------------------

! *** DEFINE AS VARIVEIS DO PROGRAMA ***

use portlib ! insero da biblioteca bsica do Fortran

implicit none

! Dados

character*50 :: caso   ! nome do arquivo de sada
character*50 :: nome   ! nome do arquivo de dados
character*90 :: titulo ! ttulo de identificao da anlise

! PONTOS ESPECIAIS:
!   N = direo norte da bssola
!   L = ponto de lanamento do espaomodelo
!   I = ponto de impacto do espaomodelo com o solo
!   O = ponto do observador com altmetro manual
!   H = apogeu do espaomodelo (altura atingida)

real*8 :: g      ! acelerao gravitacional do local do lanamento (m/s2)
real*8 :: tH     ! tempo de vo entre a decolagem e o apogeu (s)
real*8 :: tI     ! tempo de vo entre a decolagem e o impacto (s)
real*8 :: LO     ! distncia entre os pontos L e O (m)
real*8 :: alfa   ! ngulo de elevao entre OL e OH (graus)
real*8 :: LI     ! distncia entre os pontos L e I (m)
real*8 :: gama   ! ngulo de azimute entre LN e LO (graus)
real*8 :: lambda ! ngulo de azimute entre LN e LI (graus)

! Resultados

real*8 :: Hi1  ! apogeu pelo mtodo ideal 1 (m)
real*8 :: Hi2  ! apogeu pelo mtodo ideal 2 (m)
real*8 :: HA   ! apogeu pelo mtodo A (m)
real*8 :: HB   ! apogeu pelo mtodo B (m)
real*8 :: HC   ! apogeu pelo mtodo C (m)

! Variveis auxiliares

real*8 :: beta ! ngulo de azimute entre OL e LI (graus)
real*8 :: x    ! deslocamento de H, em relao a L, no sentido paralelo a OL (m)
real*8 :: y    ! deslocamento de H, em relao a L, no sentido perpendicular a OL (m)
real*8 :: OH2  ! distncia entre os pontos O e H no plano do solo (m)
real*8 :: pi   ! constante matemtica

integer :: ver

! -----------------------------------------------

! *** DEFINE O VALOR DA CONSTANTE pi
	
pi = dacos(-1.0d0)

! -----------------------------------------------------------------------------

! *** L OS DADOS ***

! Mostra o contedo do arquivo de dados do programa
ver = system("Notepad Apogeu_1p1_dados.txt")

! L o nome do arquivo com os dados numricos
open(8,file="Apogeu_1p1_dados.txt")
read(8,*) nome
close(8)

! Mostra o contedo do arquivo com os dados numricos
ver = system('notepad '//nome)

! L os dados numricos

open(8,file=nome)

read(8,*) caso
read(8,*) g
read(8,*) tH
read(8,*) tI
read(8,*) LO
read(8,*) alfa
read(8,*) LI
read(8,*) gama
read(8,*) lambda
read(8,*) titulo

close(8)

! -----------------------------------------------

! *** CALCULA O VALOR DE beta
	
beta = 180 + gama - lambda

if ( beta >= 3.6d+2 ) beta = beta - 3.6d+2

! -----------------------------------------------------------------------------

! *** CRIA O ARQUIVO DE SADA ***

open(10,file=caso)

! -----------------------------------------------------------------------------

! *** ESCREVE OS DADOS NO ARQUIVO DE SADA ***

write(10,1) trim(adjustl(caso)), trim(adjustl(titulo)), &
            g, tH, tI, LO, alfa, LI, gama, lambda, beta

1 format(/,1x, 'Sada do programa APOGEU 1.1, verso de 1 Nov 2008',//, &
           1x, 'Caso   = ', a, //, &
           1x, 'Ttulo = ', a, //, &
           3x, 'N = direo norte da bssola',/, &
           3x, 'L = ponto de lanamento do espaomodelo',/, &
           3x, 'I = ponto de impacto do espaomodelo com o solo',/, &
           3x, 'O = ponto do observador com altmetro manual',/, &
           3x, 'H = apogeu do espaomodelo (altura atingida)',//, &
        1pe15.6, ' = g      = acelerao gravitacional do local do lanamento&
                            & (m/s2)',/, &
        1pe15.6, ' = tH     = tempo de vo entre a decolagem e o apogeu (s)',/, &
        1pe15.6, ' = tI     = tempo de vo entre a decolagem e o impacto (s)',/, &
        1pe15.6, ' = LO     = distncia entre os pontos L e O (m)',/, &
        1pe15.6, ' = alfa   = ngulo de elevao entre OL e OH (graus)', /, &
        1pe15.6, ' = LI     = distncia entre os pontos L e I (m)',/, &
        1pe15.6, ' = gama   = ngulo de azimute entre LN e LO (graus)',/,&
        1pe15.6, ' = lambda = ngulo de azimute entre LN e LI (graus)',/,&
        1pe15.6, ' = beta   = ngulo de azimute entre OL e LI (graus)')

! -----------------------------------------------------------------------------

! *** MTODO IDEAL 1 ***

Hi1 = g * ( (tI/2) ** 2 ) / 2 

write(10,11) Hi1

11 format(//, 1x, '-------------- MTODO IDEAL 1: g, tI ----------------&
                  &---------------', //, &
        1pe15.6, ' = Hi1 = apogeu pelo mtodo ideal 1 (m)')

! -----------------------------------------------------------------------------

! *** MTODO IDEAL 2 ***

Hi2 = g * ( tH ** 2 ) / 2 

write(10,21) Hi2

21 format(//, 1x, '-------------- MTODO IDEAL 2: g, tH ----------------&
                  &---------------', //, &
        1pe15.6, ' = Hi2 = apogeu pelo mtodo ideal 2 (m)')

! -----------------------------------------------------------------------------

! *** MTODO A ***

HA = LO * dtan( alfa * pi / 180 ) 

write(10,31) HA

31 format(//, 1x, '-------------- MTODO A: LO, alfa --------------------&
                  &---------------', //, &
        1pe15.6, ' = HA = apogeu pelo mtodo A (m)')

! -----------------------------------------------------------------------------

! *** MTODO B ***

x = LI * dcos( beta * pi / 180 ) / 2

y = LI * dsin( beta * pi / 180 ) / 2

OH2 = dsqrt( ((LO+x)**2) + (y**2) )

HB = dtan( alfa * pi / 180 ) * OH2

write(10,41) HB, x, y, OH2

41 format(//, 1x, '-------------- MTODO B: LO, alfa, LI, beta -----------&
                  &---------------', //, &
        1pe15.6, ' = HB = apogeu pelo mtodo B (m)', //, &
    15x,1pe15.6, ' = x   (m)',/, &
    15x,1pe15.6, ' = y   (m)',/, &
    15x,1pe15.6, ' = OH2 (m)')

! -----------------------------------------------------------------------------

! *** MTODO C ***

x = LI * ( tH / tI ) * dcos( beta * pi / 180 )

y = LI * ( tH / tI ) * dsin( beta * pi / 180 )

OH2 = dsqrt( ((LO+x)**2) + (y**2) )

HC = dtan( alfa * pi / 180 ) * OH2

write(10,51) HC, x, y, OH2

51 format(//, 1x, '-------------- MTODO C: LO, alfa, LI, beta, tH, tI ---&
                  &---------------', //, &
        1pe15.6, ' = HC = apogeu pelo mtodo C (m)', //, &
    15x,1pe15.6, ' = x   (m)',/, &
    15x,1pe15.6, ' = y   (m)',/, &
    15x,1pe15.6, ' = OH2 (m)')

! -----------------------------------------------

write(10,61)

61 format(//, 1x, '-------------- DEFINIES ADICIONAIS ------------------&
                  &---------------', //, &
   'x   = deslocamento de H, em relao a L, no sentido paralelo a OL (m)',/,&
   'y   = deslocamento de H, em relao a L, no sentido perpendicular a OL (m)',/,&
   'OH2 = distncia entre os pontos O e H no plano do solo (m)')

! -----------------------------------------------

! *** FECHA O ARQUIVO DE SADA ***

close (10)

! -----------------------------------------------

! *** MOSTRA O CONTEDO DO ARQUIVO DE SADA ***

ver = system('notepad '//caso)

! -----------------------------------------------

end program Apogeu_1p1
